@@ -23,16 +23,11 @@ from ..potential.Potential import flatten as flatten_potential
 from .actionAngleIsochrone import actionAngleIsochrone
 from .actionAngle import actionAngle
 from ..potential import IsochronePotential, MWPotential
-from ..util import bovy_plot, galpyWarning
-from ..util.bovy_conversion import physical_conversion, \
+from ..util import plot, galpyWarning, conversion
+from ..util.conversion import physical_conversion, \
     potential_physical_input, time_in_Gyr
 _TWOPI= 2.*numpy.pi
 _ANGLETOL= 0.02 #tolerance for deciding whether full angle range is covered
-_APY_LOADED= True
-try:
-    from astropy import units
-except ImportError:
-    _APY_LOADED= False
 class actionAngleIsochroneApprox(actionAngle):
     """Action-angle formalism using an isochrone potential as an approximate potential and using a Fox & Binney (2014?) like algorithm to calculate the actions using orbit integrations and a torus-machinery-like angle-fit to get the angles and frequencies (Bovy 2014)"""
     def __init__(self,*args,**kwargs):
@@ -77,34 +72,29 @@ class actionAngleIsochroneApprox(actionAngle):
         actionAngle.__init__(self,
                              ro=kwargs.get('ro',None),vo=kwargs.get('vo',None))
         if not 'pot' in kwargs: #pragma: no cover
-            raise IOError("Must specify pot= for actionAngleIsochroneApprox")
+            raise OSError("Must specify pot= for actionAngleIsochroneApprox")
         self._pot= flatten_potential(kwargs['pot'])
         if self._pot == MWPotential:
             warnings.warn("Use of MWPotential as a Milky-Way-like potential is deprecated; galpy.potential.MWPotential2014, a potential fit to a large variety of dynamical constraints (see Bovy 2015), is the preferred Milky-Way-like potential in galpy",
                           galpyWarning)
         if not 'b' in kwargs and not 'ip' in kwargs \
                 and not 'aAI' in kwargs: #pragma: no cover
-            raise IOError("Must specify b=, ip=, or aAI= for actionAngleIsochroneApprox")
+            raise OSError("Must specify b=, ip=, or aAI= for actionAngleIsochroneApprox")
         if 'aAI' in kwargs:
             if not isinstance(kwargs['aAI'],actionAngleIsochrone): #pragma: no cover
-                raise IOError("'Provided aAI= does not appear to be an instance of an actionAngleIsochrone")
+                raise OSError("'Provided aAI= does not appear to be an instance of an actionAngleIsochrone")
             self._aAI= kwargs['aAI']
         elif 'ip' in kwargs:
             ip= kwargs['ip']
             if not isinstance(ip,IsochronePotential): #pragma: no cover
-                raise IOError("'Provided ip= does not appear to be an instance of an IsochronePotential")
+                raise OSError("'Provided ip= does not appear to be an instance of an IsochronePotential")
             self._aAI= actionAngleIsochrone(ip=ip)
         else:
-            if _APY_LOADED and isinstance(kwargs['b'],units.Quantity):
-                b= kwargs['b'].to(units.kpc).value/self._ro
-            else:
-                b= kwargs['b']
+            b= conversion.parse_length(kwargs['b'],ro=self._ro)
             self._aAI= actionAngleIsochrone(ip=IsochronePotential(b=b,
                                                                   normalize=1.))
         self._tintJ= kwargs.get('tintJ',100.)
-        if _APY_LOADED and isinstance(self._tintJ,units.Quantity):
-            self._tintJ= self._tintJ.to(units.Gyr).value\
-                /time_in_Gyr(self._vo,self._ro)
+        self._tintJ= conversion.parse_time(self._tintJ,ro=self._ro,vo=self._vo)
         self._ntintJ= kwargs.get('ntintJ',10000)
         self._integrate_dt= kwargs.get('dt',None)
         self._tsJ= numpy.linspace(0.,self._tintJ,self._ntintJ)
@@ -237,9 +227,7 @@ class actionAngleIsochroneApprox(actionAngle):
         R,vR,vT,z,vz,phi= self._parse_args(True,_firstFlip,*args)
         if 'ts' in kwargs and not kwargs['ts'] is None:
             ts= kwargs['ts']
-            if _APY_LOADED and isinstance(ts,units.Quantity):
-                ts= ts.to(units.Gyr).value\
-                    /time_in_Gyr(self._vo,self._ro)
+            ts= conversion.parse_time(ts,ro=self._ro,vo=self._vo)
         else:
             ts= numpy.empty(R.shape[1])
             ts[self._ntintJ-1:]= self._tsJ
@@ -430,18 +418,18 @@ class actionAngleIsochroneApprox(actionAngle):
                     plotx= ts
                     ploty= jr[0,:]/jr[0,-1]
                     plotz= anglerI[0,:-1]
-                bovy_plot.bovy_plot(plotx,ploty,
-                                    c=plotz,
-                                    s=20.,
-                                    scatter=True,
-                                    edgecolor='none',
-                                    xlabel=r'$t$',
-                                    ylabel=r'$J^A_R / \langle J^A_R \rangle$',
-                                    clabel=r'$\theta^A_R$',
-                                    vmin=0.,vmax=2.*numpy.pi,
-                                    crange=[0.,2.*numpy.pi],
-                                    colorbar=True,
-                                    **kwargs)
+                plot.plot(plotx,ploty,
+                          c=plotz,
+                          s=20.,
+                          scatter=True,
+                          edgecolor='none',
+                          xlabel=r'$t$',
+                          ylabel=r'$J^A_R / \langle J^A_R \rangle$',
+                          clabel=r'$\theta^A_R$',
+                          vmin=0.,vmax=2.*numpy.pi,
+                          crange=[0.,2.*numpy.pi],
+                          colorbar=True,
+                          **kwargs)
             elif type == 'lz':
                 if downsample:
                     plotx= ts[::int(round(self._ntintJ//400))]
@@ -451,16 +439,16 @@ class actionAngleIsochroneApprox(actionAngle):
                     plotx= ts
                     ploty= lz[0,:]/lz[0,-1]
                     plotz= anglephiI[0,:-1]
-                bovy_plot.bovy_plot(plotx,ploty,c=plotz,s=20.,
-                                    scatter=True,
-                                    edgecolor='none',
-                                    xlabel=r'$t$',
-                                    ylabel=r'$L^A_Z / \langle L^A_Z \rangle$',
-                                    clabel=r'$\theta^A_\phi$',
-                                    vmin=0.,vmax=2.*numpy.pi,
-                                    crange=[0.,2.*numpy.pi],
-                                    colorbar=True,
-                                    **kwargs)
+                plot.plot(plotx,ploty,c=plotz,s=20.,
+                          scatter=True,
+                          edgecolor='none',
+                          xlabel=r'$t$',
+                          ylabel=r'$L^A_Z / \langle L^A_Z \rangle$',
+                          clabel=r'$\theta^A_\phi$',
+                          vmin=0.,vmax=2.*numpy.pi,
+                          crange=[0.,2.*numpy.pi],
+                          colorbar=True,
+                          **kwargs)
             elif type == 'jz':
                 if downsample:
                     plotx= ts[::int(round(self._ntintJ//400))]
@@ -470,16 +458,16 @@ class actionAngleIsochroneApprox(actionAngle):
                     plotx= ts
                     ploty= jz[0,:]/jz[0,-1]
                     plotz= anglezI[0,:-1]
-                bovy_plot.bovy_plot(plotx,ploty,c=plotz,s=20.,
-                                    scatter=True,
-                                    edgecolor='none',
-                                    xlabel=r'$t$',
-                                    ylabel=r'$J^A_Z / \langle J^A_Z \rangle$',
-                                    clabel=r'$\theta^A_Z$',
-                                    vmin=0.,vmax=2.*numpy.pi,
-                                    crange=[0.,2.*numpy.pi],
-                                    colorbar=True,
-                                    **kwargs)
+                plot.plot(plotx,ploty,c=plotz,s=20.,
+                          scatter=True,
+                          edgecolor='none',
+                          xlabel=r'$t$',
+                          ylabel=r'$J^A_Z / \langle J^A_Z \rangle$',
+                          clabel=r'$\theta^A_Z$',
+                          vmin=0.,vmax=2.*numpy.pi,
+                          crange=[0.,2.*numpy.pi],
+                          colorbar=True,
+                          **kwargs)
         else:
             if deperiod:
                 if 'ar' in type:
@@ -519,17 +507,17 @@ class actionAngleIsochroneApprox(actionAngle):
                     plotx= angleRT[0,:]
                     ploty= angleZT[0,:]
                     plotz= anglephiT[0,:]
-                bovy_plot.bovy_plot(plotx,ploty,c=plotz,s=20.,
-                                    scatter=True,
-                                    edgecolor='none',
-                                    xlabel=r'$\theta^A_R$',
-                                    ylabel=r'$\theta^A_Z$',
-                                    clabel=r'$\theta^A_\phi$',
-                                    xrange=xrange,yrange=yrange,
-                                    vmin=vmin,vmax=vmax,
-                                    crange=crange,
-                                    colorbar=True,
-                                    **kwargs)           
+                plot.plot(plotx,ploty,c=plotz,s=20.,
+                          scatter=True,
+                          edgecolor='none',
+                          xlabel=r'$\theta^A_R$',
+                          ylabel=r'$\theta^A_Z$',
+                          clabel=r'$\theta^A_\phi$',
+                          xrange=xrange,yrange=yrange,
+                          vmin=vmin,vmax=vmax,
+                          crange=crange,
+                          colorbar=True,
+                          **kwargs)           
             elif type == 'araphi':
                 if downsample:
                     plotx= angleRT[0,::int(round(self._ntintJ//400))]
@@ -539,17 +527,17 @@ class actionAngleIsochroneApprox(actionAngle):
                     plotx= angleRT[0,:]
                     ploty= anglephiT[0,:]
                     plotz= angleZT[0,:]
-                bovy_plot.bovy_plot(plotx,ploty,c=plotz,s=20.,
-                                    scatter=True,
-                                    edgecolor='none',
-                                    xlabel=r'$\theta^A_R$',
-                                    clabel=r'$\theta^A_Z$',
-                                    ylabel=r'$\theta^A_\phi$',
-                                    xrange=xrange,yrange=yrange,
-                                    vmin=vmin,vmax=vmax,
-                                    crange=crange,
-                                    colorbar=True,
-                                    **kwargs)           
+                plot.plot(plotx,ploty,c=plotz,s=20.,
+                          scatter=True,
+                          edgecolor='none',
+                          xlabel=r'$\theta^A_R$',
+                          clabel=r'$\theta^A_Z$',
+                          ylabel=r'$\theta^A_\phi$',
+                          xrange=xrange,yrange=yrange,
+                          vmin=vmin,vmax=vmax,
+                          crange=crange,
+                          colorbar=True,
+                          **kwargs)           
             elif type == 'azaphi':
                 if downsample:
                     plotx= angleZT[0,::int(round(self._ntintJ//400))]
@@ -559,17 +547,17 @@ class actionAngleIsochroneApprox(actionAngle):
                     plotx= angleZT[0,:]
                     ploty= anglephiT[0,:]
                     plotz= angleRT[0,:]
-                bovy_plot.bovy_plot(plotx,ploty,c=plotz,s=20.,
-                                    scatter=True,
-                                    edgecolor='none',
-                                    clabel=r'$\theta^A_R$',
-                                    xlabel=r'$\theta^A_Z$',
-                                    ylabel=r'$\theta^A_\phi$',
-                                    xrange=xrange,yrange=yrange,
-                                    vmin=vmin,vmax=vmax,
-                                    crange=crange,
-                                    colorbar=True,
-                                    **kwargs)           
+                plot.plot(plotx,ploty,c=plotz,s=20.,
+                          scatter=True,
+                          edgecolor='none',
+                          clabel=r'$\theta^A_R$',
+                          xlabel=r'$\theta^A_Z$',
+                          ylabel=r'$\theta^A_\phi$',
+                          xrange=xrange,yrange=yrange,
+                          vmin=vmin,vmax=vmax,
+                          crange=crange,
+                          colorbar=True,
+                          **kwargs)           
         return None
 
     def _parse_args(self,freqsAngles=True,_firstFlip=False,*args):
@@ -578,13 +566,13 @@ class actionAngleIsochroneApprox(actionAngle):
         RasOrbit= False
         integrated= True #whether the orbit was already integrated when given
         if len(args) == 5 or len(args) == 3: #pragma: no cover
-            raise IOError("Must specify phi for actionAngleIsochroneApprox")
+            raise OSError("Must specify phi for actionAngleIsochroneApprox")
         if len(args) == 6 or len(args) == 4:
             if len(args) == 6:
                 R,vR,vT, z, vz, phi= args
             else:
                 R,vR,vT, phi= args
-                z, vz= 0., 0.
+                z, vz= numpy.zeros_like(R), numpy.zeros_like(R)
             if isinstance(R,float):
                 os= [Orbit([R,vR,vT,z,vz,phi])]
                 RasOrbit= True
@@ -601,11 +589,11 @@ class actionAngleIsochroneApprox(actionAngle):
             elif not isinstance(args[0],list):
                 os= [args[0]]
                 if os[0].phasedim() == 3 or os[0].phasedim() == 5: #pragma: no cover
-                    raise IOError("Must specify phi for actionAngleIsochroneApprox")
+                    raise OSError("Must specify phi for actionAngleIsochroneApprox")
             else:
                 os= args[0]
                 if os[0].phasedim() == 3 or os[0].phasedim() == 5: #pragma: no cover
-                    raise IOError("Must specify phi for actionAngleIsochroneApprox")
+                    raise OSError("Must specify phi for actionAngleIsochroneApprox")
             self._check_consistent_units_orbitInput(os[0])
             if not hasattr(os[0],'orbit'): #not integrated yet
                 if _firstFlip:
@@ -736,7 +724,7 @@ def estimateBIsochrone(pot,R,z,phi=None):
 
     """
     if pot is None: #pragma: no cover
-        raise IOError("pot= needs to be set to a Potential instance or list thereof")
+        raise OSError("pot= needs to be set to a Potential instance or list thereof")
     if isinstance(R,numpy.ndarray):
         if phi is None: phi= [None for r in R]
         bs= numpy.array([estimateBIsochrone(pot,R[ii],z[ii],phi=phi[ii],
