@@ -19,13 +19,8 @@ from .actionAngleStaeckel_c import _ext_loaded as ext_loaded
 from .. import potential
 from ..potential.Potential import _evaluatePotentials
 from ..potential.Potential import flatten as flatten_potential
-from ..util import multi, bovy_coords
+from ..util import multi, coords, conversion
 _PRINTOUTSIDEGRID= False
-_APY_LOADED= True
-try:
-    from astropy import units
-except ImportError:
-    _APY_LOADED= False
 class actionAngleStaeckelGrid(actionAngle):
     """Action-angle formalism for axisymmetric potentials using Binney (2012)'s Staeckel approximation, grid-based interpolation"""
     def __init__(self,pot=None,delta=None,Rmax=5.,
@@ -68,17 +63,15 @@ class actionAngleStaeckelGrid(actionAngle):
         actionAngle.__init__(self,
                              ro=kwargs.get('ro',None),vo=kwargs.get('vo',None))
         if pot is None:
-            raise IOError("Must specify pot= for actionAngleStaeckelGrid")
+            raise OSError("Must specify pot= for actionAngleStaeckelGrid")
         self._pot= flatten_potential(pot)
         if delta is None:
-            raise IOError("Must specify delta= for actionAngleStaeckelGrid")
+            raise OSError("Must specify delta= for actionAngleStaeckelGrid")
         if ext_loaded and 'c' in kwargs and kwargs['c']:
             self._c= True
         else:
             self._c= False
-        self._delta= delta
-        if _APY_LOADED and isinstance(self._delta,units.Quantity):
-            self._delta= self._delta.to(units.kpc).value/self._ro
+        self._delta= conversion.parse_length(delta,ro=self._ro)
         self._Rmax= Rmax
         self._Rmin= 0.01
         #Set up the actionAngleStaeckel object that we will use to interpolate
@@ -114,8 +107,8 @@ class actionAngleStaeckelGrid(actionAngle):
         jr= numpy.zeros((nLz,nE,npsi))
         jz= numpy.zeros((nLz,nE,npsi))
         u0= numpy.zeros((nLz,nE))
-        jrLzE= numpy.zeros((nLz))
-        jzLzE= numpy.zeros((nLz))
+        jrLzE= numpy.zeros(nLz)
+        jzLzE= numpy.zeros(nLz)
         #First calculate u0
         thisLzs= (numpy.tile(self._Lzs,(nE,1)).T).flatten()
         thisERL= (numpy.tile(self._ERL,(nE,1)).T).flatten()
@@ -191,9 +184,9 @@ class actionAngleStaeckelGrid(actionAngle):
             zmax= numpy.reshape(mzmax,(nLz,nE,npsi))
             rperi= numpy.reshape(mrperi,(nLz,nE,npsi))
             rap= numpy.reshape(mrap,(nLz,nE,npsi))
-            zmaxLzE= numpy.zeros((nLz))
-            rperiLzE= numpy.zeros((nLz))
-            rapLzE= numpy.zeros((nLz))
+            zmaxLzE= numpy.zeros(nLz)
+            rperiLzE= numpy.zeros(nLz)
+            rapLzE= numpy.zeros(nLz)
         for ii in range(nLz):
             jrLzE[ii]= numpy.nanmax(jr[ii,(jr[ii,:,:] != 9999.99)])#:,:])
             jzLzE[ii]= numpy.nanmax(jz[ii,(jz[ii,:,:] != 9999.99)])#:,:])
@@ -629,7 +622,7 @@ class actionAngleStaeckelGrid(actionAngle):
         HISTORY:
            2012-11-29 - Written - Bovy (IAS)
         """                           
-        u,v= bovy_coords.Rz_to_uv(R,z,self._delta)
+        u,v= coords.Rz_to_uv(R,z,self._delta)
         pu= (vR*numpy.cosh(u)*numpy.sin(v)
              +vz*numpy.sinh(u)*numpy.cos(v)) #no delta, bc we will divide it out
         out= (pu**2./2.+Lz**2./2./self._delta**2.*(1./numpy.sinh(u)**2.-1./sinh2u0)
@@ -656,7 +649,7 @@ class actionAngleStaeckelGrid(actionAngle):
         HISTORY:
            2012-12-23 - Written - Bovy (IAS)
         """                           
-        u,v= bovy_coords.Rz_to_uv(R,z,self._delta)
+        u,v= coords.Rz_to_uv(R,z,self._delta)
         pv= (vR*numpy.sinh(u)*numpy.cos(v)
              -vz*numpy.cosh(u)*numpy.sin(v)) #no delta, bc we will divide it out
         out= (pv**2./2.+Lz**2./2./self._delta**2.*(1./numpy.sin(v)**2.-1.)
@@ -677,7 +670,7 @@ def _u0Eq(logu,delta,pot,E,Lz22):
 def _Efunc(E,*args):
     """Function to apply to the energy in building the grid (e.g., if this is a log, then the grid will be logarithmic"""
 #    return ((E-args[0]))**0.5
-    return numpy.log((E-args[0]+10.**-10.))
+    return numpy.log(E-args[0]+10.**-10.)
 def _invEfunc(Ef,*args):
     """Inverse of Efunc"""
 #    return Ef**2.+args[0]
