@@ -2,10 +2,8 @@
 #   DehnenBarPotential: Dehnen (2000)'s bar potential
 ###############################################################################
 import numpy
-from ..util import bovy_conversion
-from .Potential import Potential, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+from ..util import conversion
+from .Potential import Potential
 _degtorad= numpy.pi/180.
 class DehnenBarPotential(Potential):
     """Class that implements the Dehnen bar potential (`Dehnen 2000 <http://adsabs.harvard.edu/abs/2000AJ....119..800D>`__), generalized to 3D following `Monari et al. (2016) <http://adsabs.harvard.edu/abs/2016MNRAS.461.3835M>`__
@@ -21,28 +19,28 @@ class DehnenBarPotential(Potential):
 
     .. math::
 
-        A_b(t) = A_f\\,\\left(\\frac{3}{16}\\xi^5-\\frac{5}{8}\\xi^3+\\frac{15}{16}\\xi+\\frac{1}{2}\\right)\\,, \\xi = 2\\frac{t/T_b-t_\\mathrm{form}}{T_\mathrm{steady}}-1\\,,\ \mathrm{if}\ t_\\mathrm{form} \\leq \\frac{t}{T_b} \\leq t_\\mathrm{form}+T_\\mathrm{steady}
+        A_b(t) = A_f\\,\\left(\\frac{3}{16}\\xi^5-\\frac{5}{8}\\xi^3+\\frac{15}{16}\\xi+\\frac{1}{2}\\right)\\,, \\xi = 2\\frac{t/T_b-t_\\mathrm{form}}{T_\\mathrm{steady}}-1\\,,\\ \\mathrm{if}\\ t_\\mathrm{form} \\leq \\frac{t}{T_b} \\leq t_\\mathrm{form}+T_\\mathrm{steady}
 
     and 
 
     .. math::
 
         A_b(t) = \\begin{cases}
-        0\\,, & \\frac{t}{T_b} < t_\mathrm{form}\\\\
-        A_f\\,, & \\frac{t}{T_b} > t_\mathrm{form}+T_\mathrm{steady}
+        0\\,, & \\frac{t}{T_b} < t_\\mathrm{form}\\\\
+        A_f\\,, & \\frac{t}{T_b} > t_\\mathrm{form}+T_\\mathrm{steady}
         \\end{cases}
 
     where
 
     .. math::
 
-       T_b = \\frac{2\pi}{\\Omega_b}
+       T_b = \\frac{2\\pi}{\\Omega_b}
 
     is the bar period and the strength can also be specified using :math:`\\alpha`
 
     .. math::
 
-       \\alpha = 3\\,\\frac{A_f}{v_0^2}\\,\\left(\\frac{R_b}{r_0}\\right)^3\,.
+       \\alpha = 3\\,\\frac{A_f}{v_0^2}\\,\\left(\\frac{R_b}{r_0}\\right)^3\\,.
 
     """
     normalize= property() # turn off normalize
@@ -101,17 +99,11 @@ class DehnenBarPotential(Potential):
 
         """
         Potential.__init__(self,amp=amp,ro=ro,vo=vo)
-        if _APY_LOADED and isinstance(barphi,units.Quantity):
-            barphi= barphi.to(units.rad).value
-        if _APY_LOADED and isinstance(rolr,units.Quantity):
-            rolr= rolr.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(rb,units.Quantity):
-            rb= rb.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(omegab,units.Quantity):
-            omegab= omegab.to(units.km/units.s/units.kpc).value\
-                /bovy_conversion.freq_in_kmskpc(self._vo,self._ro)
-        if _APY_LOADED and isinstance(Af,units.Quantity):
-            Af= Af.to(units.km**2/units.s**2).value/self._vo**2.
+        barphi= conversion.parse_angle(barphi)
+        rolr= conversion.parse_length(rolr,ro=self._ro)
+        rb= conversion.parse_length(rb,ro=self._ro)
+        omegab= conversion.parse_frequency(omegab,ro=self._ro,vo=self._vo)
+        Af= conversion.parse_energy(Af,vo=self._vo)
         self.hasC= True
         self.hasC_dxdv= True
         self.isNonAxi= True
@@ -137,7 +129,7 @@ class DehnenBarPotential(Potential):
             self._tsteady= self._tform+tsteady*self._tb
 
     def _smooth(self,t):
-        if isinstance(t,numpy.ndarray):
+        if isinstance(t,numpy.ndarray) and not numpy.ndim(t) == 0:
             smooth=numpy.ones(len(t))
             indx=(t < self._tform)
             smooth[indx]=0.
@@ -155,7 +147,6 @@ class DehnenBarPotential(Potential):
                 smooth= (3./16.*xi**5.-5./8*xi**3.+15./16.*xi+.5)
             else: #bar is fully on
                 smooth= 1.
-
         return smooth
 
     def _evaluate(self,R,z,phi=0.,t=0.):
@@ -181,23 +172,29 @@ class DehnenBarPotential(Potential):
         if isinstance(r,numpy.ndarray):
             if not isinstance(R,numpy.ndarray):
                 R=numpy.repeat(R,len(r))
+            if not isinstance(z,numpy.ndarray):
+                z=numpy.repeat(z,len(r))
             out=numpy.empty(len(r))
             indx= r <= self._rb  
-            out[indx]= ((r[indx]/self._rb)**3.-2.)*R[indx]**2./r2[indx]
+            out[indx]= ((r[indx]/self._rb)**3.-2.)\
+                *numpy.divide(R[indx]**2.,r2[indx],numpy.ones_like(R[indx]),
+                              where=R[indx]!=0)
             indx=numpy.invert(indx)
-            out[indx]= -(self._rb/r[indx])**3.*R[indx]**2./r2[indx] 
+            out[indx]= -(self._rb/r[indx])**3.*1./(1.+z[indx]**2./R[indx]**2.)
 
             out*=self._af*smooth*numpy.cos(2.*(phi-self._omegab*t-self._barphi))
             return out        
         else:
-            if r <= self._rb:
+            if r == 0:
+                return -2.*self._af*smooth*numpy.cos(2.*(phi-self._omegab*t-self._barphi))
+            elif r <= self._rb:
                 return self._af*smooth*numpy.cos(2.*(phi-self._omegab*t-self._barphi))\
                     *((r/self._rb)**3.-2.)*R**2./r2
             else:
                 return -self._af*smooth*numpy.cos(2.*(phi-self._omegab*t-
                                                       self._barphi))\
                                                       *(self._rb/r)**3.\
-                                                      *R**2./r2
+                                                      *1./(1.+z**2./R**2.)
 
     def _Rforce(self,R,z,phi=0.,t=0.):
         """
@@ -241,19 +238,19 @@ class DehnenBarPotential(Potential):
                                                       self._barphi))\
                         *(self._rb/r)**3.*R/r**4.*(3.*R**2.-2.*z**2.)
 
-    def _phiforce(self,R,z,phi=0.,t=0.):
+    def _phitorque(self,R,z,phi=0.,t=0.):
         """
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force for this potential
+           evaluate the azimuthal torque for this potential
         INPUT:
            R - Galactocentric cylindrical radius
            z - vertical height
            phi - azimuth
            t - time
         OUTPUT:
-           the azimuthal force
+           the azimuthal torque
         HISTORY:
            2010-11-24 - Written - Bovy (NYU)
         """
@@ -470,6 +467,48 @@ class DehnenBarPotential(Potential):
                                                       self._barphi))\
                         *(self._rb/r)**3.*R*z/r**6.*(2.*r**2.-7.*R**2.)
 
+    def _phizderiv(self,R,z,phi=0.,t=0.):
+        """
+        NAME:
+           _phizderiv
+        PURPOSE:
+           evaluate the mixed azimuthal, vertical derivative for this potential
+        INPUT:
+           R - Galactocentric cylindrical radius
+           z - vertical height
+           phi - azimuth
+           t - time
+        OUTPUT:
+           the mixed azimuthal, vertical derivative
+        HISTORY:
+           2021-04-30 - Written - Bovy (UofT)
+        """
+        #Calculate relevant time
+        smooth=self._smooth(t)
+        r= numpy.sqrt(R**2.+z**2.)
+        if isinstance(r,numpy.ndarray):
+            if not isinstance(R,numpy.ndarray):
+                R=numpy.repeat(R,len(r))
+            if not isinstance(z,numpy.ndarray):
+                z=numpy.repeat(z,len(r))
+            out=numpy.empty(len(r))
+            indx= r <= self._rb  
+            out[indx]= -((r[indx]/self._rb)**3.+4.)*R[indx]**2.*z[indx]/r[indx]**4.
+            indx=numpy.invert(indx)
+            out[indx]= -5.*(self._rb/r[indx])**3.*R[indx]**2.*z[indx]/r[indx]**4.
+
+            out*=self._af*smooth*numpy.sin(2.*(phi-self._omegab*t-self._barphi))
+            return 2.*out
+        else:
+            if r <= self._rb:
+                return -2*self._af*smooth*numpy.sin(2.*(phi-self._omegab*t
+                                                      -self._barphi))\
+                       *((r/self._rb)**3.+4.)*R**2.*z/r**4.
+            else:
+                return -10.*self._af*smooth*numpy.sin(2.*(phi-self._omegab*t-
+                                                      self._barphi))\
+                                *(self._rb/r)**3.*R**2.*z/r**4.
+
     def tform(self): #pragma: no cover
         """
         NAME:
