@@ -3,10 +3,8 @@
 #   potential
 ###############################################################################
 import numpy
-from ..util import bovy_conversion
-from .planarPotential import planarPotential, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+from ..util import conversion
+from .planarPotential import planarPotential
 _degtorad= numpy.pi/180.
 class EllipticalDiskPotential(planarPotential):
     """Class that implements the Elliptical disk potential of Kuijken & Tremaine (1994) 
@@ -15,7 +13,7 @@ class EllipticalDiskPotential(planarPotential):
 
         \\Phi(R,\\phi) = \\mathrm{amp}\\,\\phi_0\\,\\left(\\frac{R}{R_1}\\right)^p\\,\\cos\\left(2\\,(\\phi-\\phi_b)\\right)
 
-    This potential can be grown between  :math:`t_{\mathrm{form}}` and  :math:`t_{\mathrm{form}}+T_{\mathrm{steady}}` in a similar way as DehnenBarPotential, but times are given directly in galpy time units
+    This potential can be grown between  :math:`t_{\\mathrm{form}}` and  :math:`t_{\\mathrm{form}}+T_{\\mathrm{steady}}` in a similar way as DehnenBarPotential, but times are given directly in galpy time units
 
    """
     def __init__(self,amp=1.,phib=25.*_degtorad,
@@ -64,22 +62,13 @@ class EllipticalDiskPotential(planarPotential):
 
         """
         planarPotential.__init__(self,amp=amp,ro=ro,vo=vo)
-        if _APY_LOADED and isinstance(phib,units.Quantity):
-            phib= phib.to(units.rad).value
-        if _APY_LOADED and isinstance(r1,units.Quantity):
-            r1= r1.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(tform,units.Quantity):
-            tform= tform.to(units.Gyr).value\
-                /bovy_conversion.time_in_Gyr(self._vo,self._ro)
-        if _APY_LOADED and isinstance(tsteady,units.Quantity):
-            tsteady= tsteady.to(units.Gyr).value\
-                /bovy_conversion.time_in_Gyr(self._vo,self._ro)
-        if _APY_LOADED and isinstance(twophio,units.Quantity):
-            twophio= twophio.to(units.km**2/units.s**2).value/self._vo**2.
-        if _APY_LOADED and isinstance(cp,units.Quantity):
-            cp= cp.to(units.km**2/units.s**2).value/self._vo**2.
-        if _APY_LOADED and isinstance(sp,units.Quantity):
-            sp= sp.to(units.km**2/units.s**2).value/self._vo**2.
+        phib= conversion.parse_angle(phib)
+        r1= conversion.parse_length(r1,ro=self._ro)
+        tform= conversion.parse_time(tform,ro=self._ro,vo=self._vo)
+        tsteady= conversion.parse_time(tsteady,ro=self._ro,vo=self._vo)
+        twophio= conversion.parse_energy(twophio,vo=self._vo)
+        cp= conversion.parse_energy(cp,vo=self._vo)
+        sp= conversion.parse_energy(sp,vo=self._vo)
         # Back to old definition
         self._amp/= r1**p
         self.hasC= True
@@ -161,18 +150,18 @@ class EllipticalDiskPotential(planarPotential):
         return -smooth*self._p*self._twophio/2.*R**(self._p-1.)\
             *numpy.cos(2.*(phi-self._phib))
         
-    def _phiforce(self,R,phi=0.,t=0.):
+    def _phitorque(self,R,phi=0.,t=0.):
         """
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force for this potential
+           evaluate the azimuthal torque for this potential
         INPUT:
            R - Galactocentric cylindrical radius
            phi - azimuth
            t - time
         OUTPUT:
-           the azimuthal force
+           the azimuthal torque
         HISTORY:
            2011-10-19 - Written - Bovy (IAS)
         """
