@@ -11,10 +11,8 @@ import hashlib
 import numpy
 from scipy import integrate
 from scipy.special import gamma
-from ..util import bovy_conversion, bovy_coords
-from .Potential import Potential, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+from ..util import conversion, coords
+from .Potential import Potential
 
 class FerrersPotential(Potential):
     """Class that implements triaxial Ferrers potential for the ellipsoidal density profile with the short axis along the z-direction
@@ -72,13 +70,9 @@ class FerrersPotential(Potential):
 
         """
         Potential.__init__(self,amp=amp,ro=ro,vo=vo,amp_units='mass')
-        if _APY_LOADED and isinstance(a,units.Quantity):
-            a= a.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(omegab,units.Quantity):
-            omegab= omegab.to(units.km/units.s/units.kpc).value\
-                /bovy_conversion.freq_in_kmskpc(self._vo,self._ro)
-        if _APY_LOADED and isinstance(pa,units.Quantity):
-            pa= pa.to(units.rad).value
+        a= conversion.parse_length(a,ro=self._ro)
+        omegab= conversion.parse_frequency(omegab,ro=self._ro,vo=self._vo)
+        pa= conversion.parse_angle(pa)
         self.a= a
         self._scale= self.a
         if n <= 0:
@@ -117,7 +111,7 @@ class FerrersPotential(Potential):
         """
         if not self.isNonAxi:
             phi= 0.
-        x,y,z= bovy_coords.cyl_to_rect(R,phi,z)
+        x,y,z= coords.cyl_to_rect(R,phi,z)
         xy= numpy.dot(self.rot(t),numpy.array([x,y]))
         x,y= xy[0],xy[1]
         return self._evaluate_xyz(x,y,z)
@@ -147,19 +141,19 @@ class FerrersPotential(Potential):
         self._compute_xyzforces(R,z,phi,t)
         return numpy.cos(phi)*self._cached_Fx+numpy.sin(phi)*self._cached_Fy
 
-    def _phiforce(self,R,z,phi=0.,t=0.):
+    def _phitorque(self,R,z,phi=0.,t=0.):
         """
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force for this potential
+           evaluate the azimuthal torque for this potential
         INPUT:
            R - Galactocentric cylindrical radius
            z - vertical height
            phi - azimuth
            t - time
         OUTPUT:
-           the azimuthal force
+           the azimuthal torque
         """
         if not self.isNonAxi:
             phi= 0.
@@ -187,7 +181,7 @@ class FerrersPotential(Potential):
         return self._cached_Fz
 
     def _compute_xyz(self,R,phi,z,t):
-        return bovy_coords.cyl_to_rect(R,phi-self._pa-self._omegab*t,z)
+        return coords.cyl_to_rect(R,phi-self._pa-self._omegab*t,z)
 
     def _compute_xyzforces(self,R,z,phi,t):
         # Compute all rectangular forces
@@ -364,8 +358,33 @@ class FerrersPotential(Potential):
             (phiyy-phixx)+R*numpy.cos(2.*(phi))*phixy\
             +numpy.sin(phi)*Fx-numpy.cos(phi)*Fy
 
+    def _phizderiv(self,R,z,phi=0.,t=0.):
+        """
+        NAME:
+           _phizderiv
+        PURPOSE:
+           evaluate the mixed azimuthal, vertical derivative for this potential
+        INPUT:
+           R - Galactocentric cylindrical radius
+           z - vertical height
+           phi - azimuth
+           t - time
+        OUTPUT:
+           the mixed azimuthal, vertical derivative
+        HISTORY:
+           2021-04-30 - Written - Bovy (UofT)
+        """
+        if not self.isNonAxi:
+            phi= 0.
+        x,y,z= self._compute_xyz(R,phi,z,t)
+        phixza= self._2ndderiv_xyz(x,y,z,0,2)
+        phiyza= self._2ndderiv_xyz(x,y,z,1,2)
+        phixz, phiyz= numpy.dot(self.rot(t,transposed=True),
+                                numpy.array([phixza,phiyza]))
+        return R*(numpy.cos(phi)*phiyz-numpy.sin(phi)*phixz)
+
     def _2ndderiv_xyz(self,x,y,z,i,j):
-        """General 2nd derivative of the potential as a function of (x,y,z)
+        r"""General 2nd derivative of the potential as a function of (x,y,z)
         in the aligned coordinate frame, d^2\Phi/dx_i/dx_j"""
         return -numpy.pi*self._rhoc_M*self.a**3*self._b*self._c *\
             _2ndDerivInt(x,y,z,self._a2,self._b2*self._a2,self._c2*self._a2,self.n,i,j)
@@ -440,7 +459,7 @@ def _forceInt(x,y,z,a2,b2,c2,n,i):
     return integrate.quad(integrand, lowerlim(x**2, y**2, z**2, a2, b2, c2), numpy.inf, epsabs=1e-12)[0]
 
 def _2ndDerivInt(x,y,z,a2,b2,c2,n,i,j):
-    """Integral involved in second derivatives d^\Phi/(dx_i dx_j)
+    r"""Integral involved in second derivatives d^\Phi/(dx_i dx_j)
     integrate
         1/A B^(n-1) (-2 x_i/(tau+a_i)) (-2 x_j/(tau+a_j))
     when i /= j or
