@@ -4,10 +4,8 @@
 ###############################################################################
 import warnings
 import numpy
-from .Potential import Potential, kms_to_kpcGyrDecorator, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
-from ..util import galpyWarning
+from .Potential import Potential, kms_to_kpcGyrDecorator
+from ..util import galpyWarning, conversion
 _CORE=10**-8
 class LogarithmicHaloPotential(Potential):
     """Class that implements the logarithmic potential
@@ -22,7 +20,7 @@ class LogarithmicHaloPotential(Potential):
 
         \\Phi(x,y,z) = \\frac{\\mathrm{amp}}{2}\\,\\ln\\left[x^2+\\left(\\frac{y}{b}\\right)^2+\\left(\\frac{z}{q}\\right)^2+\\mathrm{core}^2\\right]
 
-    With these definitions, :math:`\\sqrt{\mathrm{amp}}` is the circular velocity at :math:`r \gg \mathrm{core}` at :math:`(y,z) = (0,0)`.
+    With these definitions, :math:`\\sqrt{\\mathrm{amp}}` is the circular velocity at :math:`r \\gg \\mathrm{core}` at :math:`(y,z) = (0,0)`.
 
     """
     def __init__(self,amp=1.,core=_CORE,q=1.,b=None,normalize=False,
@@ -60,8 +58,7 @@ class LogarithmicHaloPotential(Potential):
 
         """
         Potential.__init__(self,amp=amp,ro=ro,vo=vo,amp_units='velocity2')
-        if _APY_LOADED and isinstance(core,units.Quantity):
-            core= core.to(units.kpc).value/self._ro
+        core= conversion.parse_length(core,ro=self._ro)
         self.hasC= True
         self.hasC_dxdv= True
         self.hasC_dens= True
@@ -143,19 +140,19 @@ class LogarithmicHaloPotential(Potential):
         else:
             return -z/self._q**2./(R**2.+(z/self._q)**2.+self._core2)
 
-    def _phiforce(self,R,z,phi=0.,t=0.):
+    def _phitorque(self,R,z,phi=0.,t=0.):
         """
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force for this potential
+           evaluate the azimuthal torque for this potential
         INPUT:
            R - Galactocentric cylindrical radius
            z - vertical height
            phi - azimuth
            t - time
         OUTPUT:
-           the azimuthal force
+           the azimuthal torque
         HISTORY:
         """
         if self.isNonAxi:
@@ -315,6 +312,30 @@ class LogarithmicHaloPotential(Potential):
         else:
             return 0.
 
+    def _phizderiv(self,R,z,phi=0.,t=0.):
+        """
+        NAME:
+           _phizderiv
+        PURPOSE:
+           evaluate the mixed phi,z derivative for this potential
+        INPUT:
+           R - Galactocentric cylindrical radius
+           z - vertical height
+           phi - azimuth
+           t - time
+        OUTPUT:
+           d2Phi/dz/dphi
+        HISTORY:
+           2021-04-30 - Written - Bovy (UofT)
+        """
+        if self.isNonAxi:
+            Rt2= R**2.*(1.-self._1m1overb2*numpy.sin(phi)**2.)
+            denom= 1./(Rt2+(z/self._q)**2.+self._core2)
+            return 2*R**2*z*numpy.sin(phi)*numpy.cos(phi)*self._1m1overb2\
+                *denom**2/self._q**2
+        else:
+            return 0.
+
     @kms_to_kpcGyrDecorator
     def _nemo_accpars(self,vo,ro):
         """
@@ -343,6 +364,6 @@ class LogarithmicHaloPotential(Potential):
         """
         warnings.warn("NEMO's LogPot does not allow flattening in z (for some reason); therefore, flip y and z in NEMO wrt galpy; also does not allow the triaxial b parameter",galpyWarning)
         ampl= self._amp*vo**2.
-        return "0,%s,%s,1.0,%s" % (ampl,
+        return "0,{},{},1.0,{}".format(ampl,
                                   self._core2*ro**2.*self._q**(2./3.), #somewhat weird gyrfalcon implementation
                                   self._q)
