@@ -6,10 +6,8 @@
 ###############################################################################
 import warnings
 import numpy
-from ..util import galpyWarning
-from .Potential import Potential, kms_to_kpcGyrDecorator, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+from ..util import galpyWarning, conversion
+from .Potential import Potential, kms_to_kpcGyrDecorator
 from .MiyamotoNagaiPotential import MiyamotoNagaiPotential
 class MN3ExponentialDiskPotential(Potential):
     """class that implements the three Miyamoto-Nagai approximation to a radially-exponential disk potential of `Smith et al. 2015 <http://adsabs.harvard.edu/abs/2015arXiv150200627S>`_
@@ -66,10 +64,8 @@ class MN3ExponentialDiskPotential(Potential):
 
         """
         Potential.__init__(self,amp=amp,ro=ro,vo=vo,amp_units='density')
-        if _APY_LOADED and isinstance(hr,units.Quantity):
-            hr= hr.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(hz,units.Quantity):
-            hz= hz.to(units.kpc).value/self._ro
+        hr= conversion.parse_length(hr,ro=self._ro)
+        hz= conversion.parse_length(hz,ro=self._ro)
         self._hr= hr
         self._hz= hz
         self._scale= self._hr
@@ -81,7 +77,7 @@ class MN3ExponentialDiskPotential(Potential):
         else:
             self._brd= _b_exphz(self._hz/self._hr)
         if self._brd < 0.:
-            raise IOError("MN3ExponentialDiskPotential's b/Rd is negative for the given hz")
+            raise OSError("MN3ExponentialDiskPotential's b/Rd is negative for the given hz")
         # Check range
         if (not posdens and self._brd > 3.) \
                 or (posdens and self._brd > 1.35):
@@ -289,7 +285,7 @@ class MN3ExponentialDiskPotential(Potential):
         for ii in range(3):
             if ii > 0: out+= '#'
             ampl= self._amp*self._mn3[ii]._amp*vo**2.*ro
-            out+= "0,%s,%s,%s" % (ampl,self._mn3[ii]._a*ro,self._mn3[ii]._b*ro)
+            out+= "0,{},{},{}".format(ampl,self._mn3[ii]._a*ro,self._mn3[ii]._b*ro)
         return out
 
 # Equations from Table 1
