@@ -6,9 +6,8 @@
 #                                             \sqrt(R^2+(a+\sqrt(z^2+b^2))^2)
 ###############################################################################
 import numpy
-from .Potential import Potential, kms_to_kpcGyrDecorator, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+from ..util import conversion
+from .Potential import Potential, kms_to_kpcGyrDecorator
 class MiyamotoNagaiPotential(Potential):
     """Class that implements the Miyamoto-Nagai potential
 
@@ -51,10 +50,8 @@ class MiyamotoNagaiPotential(Potential):
 
         """
         Potential.__init__(self,amp=amp,ro=ro,vo=vo,amp_units='mass')
-        if _APY_LOADED and isinstance(a,units.Quantity):
-            a= a.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(b,units.Quantity):
-            b= b.to(units.kpc).value/self._ro
+        a= conversion.parse_length(a,ro=self._ro)
+        b= conversion.parse_length(b,ro=self._ro)
         self._a= a
         self._scale= self._a
         self._b= b
@@ -252,4 +249,4 @@ class MiyamotoNagaiPotential(Potential):
 
         """
         ampl= self._amp*vo**2.*ro
-        return "0,%s,%s,%s" % (ampl,self._a*ro,self._b*ro)
+        return "0,{},{},{}".format(ampl,self._a*ro,self._b*ro)
