@@ -4,10 +4,8 @@
 ###############################################################################
 import hashlib
 import numpy
-from .Potential import Potential, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
-from ..util import bovy_coords, bovy_conversion
+from .Potential import Potential
+from ..util import coords, conversion
 class SoftenedNeedleBarPotential(Potential):
     """Class that implements the softened needle bar potential from `Long & Murali (1992) <http://adsabs.harvard.edu/abs/1992ApJ...397...44L>`__
 
@@ -63,17 +61,11 @@ class SoftenedNeedleBarPotential(Potential):
 
         """
         Potential.__init__(self,amp=amp,ro=ro,vo=vo,amp_units='mass')
-        if _APY_LOADED and isinstance(a,units.Quantity):
-            a= a.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(b,units.Quantity):
-            b= b.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(c,units.Quantity):
-            c= c.to(units.kpc).value/self._ro
-        if _APY_LOADED and isinstance(pa,units.Quantity):
-            pa= pa.to(units.rad).value
-        if _APY_LOADED and isinstance(omegab,units.Quantity):
-            omegab= omegab.to(units.km/units.s/units.kpc).value\
-                /bovy_conversion.freq_in_kmskpc(self._vo,self._ro)
+        a= conversion.parse_length(a,ro=self._ro)
+        b= conversion.parse_length(b,ro=self._ro)
+        c= conversion.parse_length(c,ro=self._ro)
+        pa= conversion.parse_angle(pa)
+        omegab= conversion.parse_frequency(omegab,ro=self._ro,vo=self._vo)
         self._a= a
         self._b= b
         self._c2= c**2.
@@ -128,19 +120,19 @@ class SoftenedNeedleBarPotential(Potential):
         self._compute_xyzforces(R,z,phi,t)
         return numpy.cos(phi)*self._cached_Fx+numpy.sin(phi)*self._cached_Fy
 
-    def _phiforce(self,R,z,phi=0.,t=0.):
+    def _phitorque(self,R,z,phi=0.,t=0.):
         """
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force for this potential
+           evaluate the azimuthal torque for this potential
         INPUT:
            R - Galactocentric cylindrical radius
            z - vertical height
            phi - azimuth
            t - time
         OUTPUT:
-           the azimuthal force
+           the azimuthal torque
         HISTORY:
            2016-11-02 - Written - Bovy (UofT)
         """
@@ -183,7 +175,7 @@ class SoftenedNeedleBarPotential(Potential):
         return self._omegab
 
     def _compute_xyz(self,R,phi,z,t):
-        return bovy_coords.cyl_to_rect(R,phi-self._pa-self._omegab*t,z)
+        return coords.cyl_to_rect(R,phi-self._pa-self._omegab*t,z)
 
     def _compute_TpTm(self,x,y,z):
         secondpart= y**2.+(self._b+numpy.sqrt(self._c2+z**2.))**2.
