@@ -2,20 +2,18 @@
 #   SteadyLogSpiralPotential: a steady-state spiral potential
 ###############################################################################
 import numpy
-from ..util import bovy_conversion
-from .planarPotential import planarPotential, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+from ..util import conversion
+from .planarPotential import planarPotential
 _degtorad= numpy.pi/180.
 class SteadyLogSpiralPotential(planarPotential):
     """Class that implements a steady-state spiral potential
     
     .. math::
 
-        \\Phi(R,\\phi) = \\frac{\\mathrm{amp}\\times A}{\\alpha}\\,\\cos\\left(\\alpha\,\ln R - m\\,(\\phi-\\Omega_s\\,t-\\gamma)\\right)
+        \\Phi(R,\\phi) = \\frac{\\mathrm{amp}\\times A}{\\alpha}\\,\\cos\\left(\\alpha\\,\\ln R - m\\,(\\phi-\\Omega_s\\,t-\\gamma)\\right)
 
 
-    Can be grown in a similar way as the DehnenBarPotential, but using :math:`T_s = 2\pi/\Omega_s` to normalize :math:`t_{\mathrm{form}}` and :math:`T_{\mathrm{steady}}`.
+    Can be grown in a similar way as the DehnenBarPotential, but using :math:`T_s = 2\\pi/\\Omega_s` to normalize :math:`t_{\\mathrm{form}}` and :math:`T_{\\mathrm{steady}}`.
 
     """
     def __init__(self,amp=1.,omegas=0.65,A=-0.035,
@@ -63,15 +61,10 @@ class SteadyLogSpiralPotential(planarPotential):
 
         """
         planarPotential.__init__(self,amp=amp,ro=ro,vo=vo)
-        if _APY_LOADED and isinstance(gamma,units.Quantity):
-            gamma= gamma.to(units.rad).value
-        if _APY_LOADED and isinstance(p,units.Quantity):
-            p= p.to(units.rad).value
-        if _APY_LOADED and isinstance(A,units.Quantity):
-            A= A.to(units.km**2/units.s**2).value/self._vo**2.
-        if _APY_LOADED and isinstance(omegas,units.Quantity):
-            omegas= omegas.to(units.km/units.s/units.kpc).value\
-                /bovy_conversion.freq_in_kmskpc(self._vo,self._ro)
+        gamma= conversion.parse_angle(gamma)
+        p= conversion.parse_angle(p)
+        A= conversion.parse_energy(A,vo=self._vo)
+        omegas= conversion.parse_frequency(omegas,ro=self._ro,vo=self._vo)
         self._omegas= omegas
         self._A= A
         self._m= m
@@ -152,18 +145,18 @@ class SteadyLogSpiralPotential(planarPotential):
                                          -self._m*(phi-self._omegas*t
                                                    -self._gamma))
        
-    def _phiforce(self,R,phi=0.,t=0.):
+    def _phitorque(self,R,phi=0.,t=0.):
         """
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force for this potential
+           evaluate the azimuthal torque for this potential
         INPUT:
            R - Galactocentric cylindrical radius
            phi - azimuth
            t - time
         OUTPUT:
-           the azimuthal force
+           the azimuthal torque
         HISTORY:
            2010-11-24 - Written - Bovy (NYU)
         """
