@@ -2,17 +2,15 @@
 #   TransientLogSpiralPotential: a transient spiral potential
 ###############################################################################
 import numpy
-from ..util import bovy_conversion
-from .planarPotential import planarPotential, _APY_LOADED
-if _APY_LOADED:
-    from astropy import units
+from ..util import conversion
+from .planarPotential import planarPotential
 _degtorad= numpy.pi/180.
 class TransientLogSpiralPotential(planarPotential):
     """Class that implements a steady-state spiral potential
     
     .. math::
 
-        \\Phi(R,\\phi) = \\frac{\\mathrm{amp}(t)}{\\alpha}\\,\\cos\\left(\\alpha\,\ln R - m\\,(\\phi-\\Omega_s\\,t-\\gamma)\\right)
+        \\Phi(R,\\phi) = \\frac{\\mathrm{amp}(t)}{\\alpha}\\,\\cos\\left(\\alpha\\,\\ln R - m\\,(\\phi-\\Omega_s\\,t-\\gamma)\\right)
 
     where
 
@@ -67,21 +65,12 @@ class TransientLogSpiralPotential(planarPotential):
 
         """
         planarPotential.__init__(self,amp=amp,ro=ro,vo=vo)
-        if _APY_LOADED and isinstance(gamma,units.Quantity):
-            gamma= gamma.to(units.rad).value
-        if _APY_LOADED and isinstance(p,units.Quantity):
-            p= p.to(units.rad).value
-        if _APY_LOADED and isinstance(A,units.Quantity):
-            A= A.to(units.km**2/units.s**2).value/self._vo**2.
-        if _APY_LOADED and isinstance(omegas,units.Quantity):
-            omegas= omegas.to(units.km/units.s/units.kpc).value\
-                /bovy_conversion.freq_in_kmskpc(self._vo,self._ro)
-        if _APY_LOADED and isinstance(to,units.Quantity):
-            to= to.to(units.Gyr).value\
-                /bovy_conversion.time_in_Gyr(self._vo,self._ro)
-        if _APY_LOADED and isinstance(sigma,units.Quantity):
-            sigma= sigma.to(units.Gyr).value\
-                /bovy_conversion.time_in_Gyr(self._vo,self._ro)
+        gamma= conversion.parse_angle(gamma)
+        p= conversion.parse_angle(p)
+        A= conversion.parse_energy(A,vo=self._vo)
+        omegas= conversion.parse_frequency(omegas,ro=self._ro,vo=self._vo)
+        to= conversion.parse_time(to,ro=self._ro,vo=self._vo)
+        sigma= conversion.parse_time(sigma,ro=self._ro,vo=self._vo)
         self._omegas= omegas
         self._A= A
         self._m= m
@@ -132,18 +121,18 @@ class TransientLogSpiralPotential(planarPotential):
             /R*numpy.sin(self._alpha*numpy.log(R)
                         -self._m*(phi-self._omegas*t-self._gamma))
     
-    def _phiforce(self,R,phi=0.,t=0.):
+    def _phitorque(self,R,phi=0.,t=0.):
         """
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force for this potential
+           evaluate the azimuthal torque for this potential
         INPUT:
            R - Galactocentric cylindrical radius
            phi - azimuth
            t - time
         OUTPUT:
-           the azimuthal force
+           the azimuthal torque
         HISTORY:
            2010-11-24 - Written - Bovy (NYU)
         """
