@@ -12,10 +12,8 @@
 ###############################################################################
 import numpy
 from scipy import special
-from .Potential import _APY_LOADED
+from ..util import conversion
 from .EllipsoidalPotential import EllipsoidalPotential
-if _APY_LOADED:
-    from astropy import units
 class TwoPowerTriaxialPotential(EllipsoidalPotential):
     """Class that implements triaxial potentials that are derived from 
     two-power density models
@@ -84,12 +82,11 @@ class TwoPowerTriaxialPotential(EllipsoidalPotential):
         EllipsoidalPotential.__init__(self,amp=amp,b=b,c=c,
                                       zvec=zvec,pa=pa,glorder=glorder,
                                       ro=ro,vo=vo,amp_units='mass')
-        if _APY_LOADED and isinstance(a,units.Quantity):
-            a= a.to(units.kpc).value/self._ro
+        a= conversion.parse_length(a,ro=self._ro)
         self.a= a
         self._scale= self.a
         if beta <= 2. or alpha >= 3.:
-            raise IOError('TwoPowerTriaxialPotential requires 0 <= alpha < 3 and beta > 2')
+            raise OSError('TwoPowerTriaxialPotential requires 0 <= alpha < 3 and beta > 2')
         self.alpha= alpha
         self.beta= beta
         self.betaminusalpha= self.beta-self.alpha
@@ -108,7 +105,7 @@ class TwoPowerTriaxialPotential(EllipsoidalPotential):
         return None
 
     def _psi(self,m):
-        """\psi(m) = -\int_m^\infty d m^2 \rho(m^2)"""
+        """\\psi(m) = -\\int_m^\\infty d m^2 \rho(m^2)"""
         if self.twominusalpha == 0.:
             return -2.*self.a**2*(self.a/m)**self.betaminusalpha\
                       /self.betaminusalpha\
@@ -133,6 +130,27 @@ class TwoPowerTriaxialPotential(EllipsoidalPotential):
         """Derivative of the density as a function of m"""
         return -self._mdens(m)*(self.a*self.alpha+self.beta*m)/m/(self.a+m)
 
+    def _mass(self,R,z=None,t=0.):
+        """
+        NAME:
+           _mass
+        PURPOSE:
+           evaluate the mass within R (and z) for this potential; if z=None, integrate to ellipsoidal boundary
+        INPUT:
+           R - Galactocentric cylindrical radius
+           z - vertical height
+           t - time
+        OUTPUT:
+           the mass enclosed
+        HISTORY:
+           2021-03-09 - Written - Bovy (UofT)
+        """
+        if not z is None: raise AttributeError # Hack to fall back to general
+        return 4.*numpy.pi*self.a**self.alpha\
+            *R**(3.-self.alpha)/(3.-self.alpha)*self._b*self._c\
+            *special.hyp2f1(3.-self.alpha,self.betaminusalpha,
+                            4.-self.alpha,-R/self.a)
+
 class TriaxialHernquistPotential(EllipsoidalPotential):
     """Class that implements the triaxial Hernquist potential
 
@@ -194,8 +212,7 @@ class TriaxialHernquistPotential(EllipsoidalPotential):
         EllipsoidalPotential.__init__(self,amp=amp,b=b,c=c,
                                       zvec=zvec,pa=pa,glorder=glorder,
                                       ro=ro,vo=vo,amp_units='mass')
-        if _APY_LOADED and isinstance(a,units.Quantity):
-            a= a.to(units.kpc).value/self._ro
+        a= conversion.parse_length(a,ro=self._ro)
         self.a= a
         self._scale= self.a
         # Adjust amp
@@ -211,7 +228,7 @@ class TriaxialHernquistPotential(EllipsoidalPotential):
         return None
 
     def _psi(self,m):
-        """\psi(m) = -\int_m^\infty d m^2 \rho(m^2)"""
+        """\\psi(m) = -\\int_m^\\infty d m^2 \rho(m^2)"""
         return -self.a4/(m+self.a)**2.
 
     def _mdens(self,m):
@@ -222,6 +239,24 @@ class TriaxialHernquistPotential(EllipsoidalPotential):
         """Derivative of the density as a function of m"""
         return -self.a4*(self.a+4.*m)/m**2/(self.a+m)**4
 
+    def _mass(self,R,z=None,t=0.):
+        """
+        NAME:
+           _mass
+        PURPOSE:
+           evaluate the mass within R (and z) for this potential; if z=None, integrate to ellipsoidal boundary
+        INPUT:
+           R - Galactocentric cylindrical radius
+           z - vertical height
+           t - time
+        OUTPUT:
+           the mass enclosed
+        HISTORY:
+           2021-03-16 - Written - Bovy (UofT)
+        """
+        if not z is None: raise AttributeError # Hack to fall back to general
+        return 4.*numpy.pi*self.a4/self.a/(1.+self.a/R)**2./2.*self._b*self._c
+    
 class TriaxialJaffePotential(EllipsoidalPotential):
     """Class that implements the Jaffe potential
 
@@ -283,8 +318,7 @@ class TriaxialJaffePotential(EllipsoidalPotential):
         EllipsoidalPotential.__init__(self,amp=amp,b=b,c=c,
                                       zvec=zvec,pa=pa,glorder=glorder,
                                       ro=ro,vo=vo,amp_units='mass')
-        if _APY_LOADED and isinstance(a,units.Quantity):
-            a= a.to(units.kpc).value/self._ro
+        a= conversion.parse_length(a,ro=self._ro)
         self.a= a
         self._scale= self.a
         # Adjust amp
@@ -300,8 +334,8 @@ class TriaxialJaffePotential(EllipsoidalPotential):
         return None
 
     def _psi(self,m):
-        """\psi(m) = -\int_m^\infty d m^2 \rho(m^2)"""
-        return 2.*self.a2*(1./(1.+m/self.a)+numpy.log(m/(m+self.a)))
+        """\\psi(m) = -\\int_m^\\infty d m^2 \rho(m^2)"""
+        return 2.*self.a2*(1./(1.+m/self.a)+numpy.log(1./(1.+self.a/m)))
 
     def _mdens(self,m):
         """Density as a function of m"""
@@ -311,6 +345,24 @@ class TriaxialJaffePotential(EllipsoidalPotential):
         """Derivative of the density as a function of m"""
         return -2.*self.a2**2*(self.a+2.*m)/m**3/(self.a+m)**3
   
+    def _mass(self,R,z=None,t=0.):
+        """
+        NAME:
+           _mass
+        PURPOSE:
+           evaluate the mass within R (and z) for this potential; if z=None, integrate to ellipsoidal boundary
+        INPUT:
+           R - Galactocentric cylindrical radius
+           z - vertical height
+           t - time
+        OUTPUT:
+           the mass enclosed
+        HISTORY:
+           2021-03-16 - Written - Bovy (UofT)
+        """
+        if not z is None: raise AttributeError # Hack to fall back to general
+        return 4.*numpy.pi*self.a*self.a2/(1.+self.a/R)*self._b*self._c
+    
 class TriaxialNFWPotential(EllipsoidalPotential):
     """Class that implements the triaxial NFW potential
 
@@ -392,8 +444,7 @@ class TriaxialNFWPotential(EllipsoidalPotential):
         EllipsoidalPotential.__init__(self,amp=amp,b=b,c=c,
                                       zvec=zvec,pa=pa,glorder=glorder,
                                       ro=ro,vo=vo,amp_units='mass')
-        if _APY_LOADED and isinstance(a,units.Quantity):
-            a= a.to(units.kpc).value/self._ro
+        a= conversion.parse_length(a,ro=self._ro)
         if conc is None:
             self.a= a
         else:
@@ -416,7 +467,7 @@ class TriaxialNFWPotential(EllipsoidalPotential):
         return None
 
     def _psi(self,m):
-        """\psi(m) = -\int_m^\infty d m^2 \rho(m^2)"""
+        """\\psi(m) = -\\int_m^\\infty d m^2 \rho(m^2)"""
         return -2.*self.a3/(self.a+m)
 
     def _mdens(self,m):
@@ -426,3 +477,23 @@ class TriaxialNFWPotential(EllipsoidalPotential):
     def _mdens_deriv(self,m):
         """Derivative of the density as a function of m"""
         return -self.a3*(self.a+3.*m)/m**2/(self.a+m)**3
+
+    def _mass(self,R,z=None,t=0.):
+        """
+        NAME:
+           _mass
+        PURPOSE:
+           evaluate the mass within R (and z) for this potential; if z=None, integrate to ellipsoidal boundary
+        INPUT:
+           R - Galactocentric cylindrical radius
+           z - vertical height
+           t - time
+        OUTPUT:
+           the mass enclosed
+        HISTORY:
+           2021-03-16 - Written - Bovy (UofT)
+        """
+        if not z is None: raise AttributeError # Hack to fall back to general
+        return 4.*numpy.pi*self.a3*self._b*self._c\
+            *(numpy.log(1+R/self.a)-R/self.a/(1.+R/self.a))
+    
