@@ -7,7 +7,7 @@ from numpy.ctypeslib import ndpointer
 from scipy import interpolate
 from ..util import multi
 from .Potential import Potential
-from ..util.bovy_conversion import physical_conversion
+from ..util.conversion import physical_conversion
 from ..util import _load_extension_libs
 _DEBUG= False
 
@@ -308,7 +308,7 @@ class interpRZPotential(Potential):
     def _evaluate(self,R,z,phi=0.,t=0.):
         from ..potential import evaluatePotentials
         if self._interpPot:
-            out= numpy.empty_like(R)
+            out= numpy.empty(R.shape)
             indx= (R >= self._rgrid[0])*(R <= self._rgrid[-1])\
                 *(z <= self._zgrid[-1])*(z >= self._zgrid[0])
             if numpy.sum(indx) > 0:
@@ -332,7 +332,7 @@ class interpRZPotential(Potential):
     def _Rforce(self,R,z,phi=0.,t=0.):
         from ..potential import evaluateRforces
         if self._interpRforce:
-            out= numpy.empty_like(R)
+            out= numpy.empty(R.shape)
             indx= (R >= self._rgrid[0])*(R <= self._rgrid[-1])\
                 *(z <= self._zgrid[-1])*(z >= self._zgrid[0])
             if numpy.sum(indx) > 0:
@@ -356,7 +356,7 @@ class interpRZPotential(Potential):
     def _zforce(self,R,z,phi=0.,t=0.):
         from ..potential import evaluatezforces
         if self._interpzforce:
-            out= numpy.empty_like(R)
+            out= numpy.empty(R.shape)
             indx= (R >= self._rgrid[0])*(R <= self._rgrid[-1])\
                 *(z <= self._zgrid[-1])*(z >= self._zgrid[0])
             if numpy.sum(indx) > 0:
@@ -386,7 +386,7 @@ class interpRZPotential(Potential):
     def _dens(self,R,z,phi=0.,t=0.):
         from ..potential import evaluateDensities
         if self._interpDens:
-            out= numpy.empty_like(R)
+            out= numpy.empty(R.shape)
             indx= (R >= self._rgrid[0])*(R <= self._rgrid[-1])\
                 *(z <= self._zgrid[-1])*(z >= self._zgrid[0])
             if numpy.sum(indx) > 0:
@@ -408,7 +408,7 @@ class interpRZPotential(Potential):
         from ..potential import vcirc
         if self._interpvcirc:
             indx= (R >= self._rgrid[0])*(R <= self._rgrid[-1])
-            out= numpy.empty_like(R)
+            out= numpy.empty(R.shape)
             if numpy.sum(indx) > 0:
                 if self._logR:
                     out[indx]= self._vcircInterp(numpy.log(R[indx]))
@@ -426,7 +426,7 @@ class interpRZPotential(Potential):
         from ..potential import dvcircdR
         if self._interpdvcircdr:
             indx= (R >= self._rgrid[0])*(R <= self._rgrid[-1])
-            out= numpy.empty_like(R)
+            out= numpy.empty(R.shape)
             if numpy.sum(indx) > 0:
                 if self._logR:
                     out[indx]= self._dvcircdrInterp(numpy.log(R[indx]))
@@ -444,7 +444,7 @@ class interpRZPotential(Potential):
         from ..potential import epifreq
         if self._interpepifreq:
             indx= (R >= self._rgrid[0])*(R <= self._rgrid[-1])
-            out= numpy.empty_like(R)
+            out= numpy.empty(R.shape)
             if numpy.sum(indx) > 0:
                 if self._logR:
                     out[indx]= self._epifreqInterp(numpy.log(R[indx]))
@@ -462,7 +462,7 @@ class interpRZPotential(Potential):
         from ..potential import verticalfreq
         if self._interpverticalfreq:
             indx= (R >= self._rgrid[0])*(R <= self._rgrid[-1])
-            out= numpy.empty_like(R)
+            out= numpy.empty(R.shape)
             if numpy.sum(indx) > 0:
                 if self._logR:
                     out[indx]= self._verticalfreqInterp(numpy.log(R[indx]))
@@ -492,8 +492,10 @@ def calc_potential_c(pot,R,z,rforce=False,zforce=False):
        2013-01-29 - Added forces - Bovy (IAS)
     """
     from ..orbit.integrateFullOrbit import _parse_pot #here bc otherwise there is an infinite loop
+    from ..orbit.integratePlanarOrbit import _prep_tfuncs
     #Parse the potential
-    npot, pot_type, pot_args= _parse_pot(pot)
+    npot, pot_type, pot_args, pot_tfuncs= _parse_pot(pot)
+    pot_tfuncs= _prep_tfuncs(pot_tfuncs)
 
     #Set up result arrays
     out= numpy.empty((len(R),len(z)))
@@ -514,6 +516,7 @@ def calc_potential_c(pot,R,z,rforce=False,zforce=False):
                                                   ctypes.c_int,
                                                   ndpointer(dtype=numpy.int32,flags=ndarrayFlags),
                                                   ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
+                                                  ctypes.c_void_p,
                                                   ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
                                                   ctypes.POINTER(ctypes.c_int)]
 
@@ -532,6 +535,7 @@ def calc_potential_c(pot,R,z,rforce=False,zforce=False):
                                        ctypes.c_int(npot),
                                        pot_type,
                                        pot_args,
+                                       pot_tfuncs,
                                        out,
                                        ctypes.byref(err))
     
@@ -586,11 +590,13 @@ def eval_potential_c(pot,R,z):
        2013-01-24 - Written - Bovy (IAS)
     """
     from ..orbit.integrateFullOrbit import _parse_pot #here bc otherwise there is an infinite loop
+    from ..orbit.integratePlanarOrbit import _prep_tfuncs
     #Parse the potential
-    npot, pot_type, pot_args= _parse_pot(pot,potforactions=True)
+    npot, pot_type, pot_args, pot_tfuncs= _parse_pot(pot,potforactions=True)
+    pot_tfuncs= _prep_tfuncs(pot_tfuncs)
 
     #Set up result arrays
-    out= numpy.empty((len(R)))
+    out= numpy.empty(len(R))
     err= ctypes.c_int(0)
 
     #Set up the C code
@@ -602,6 +608,7 @@ def eval_potential_c(pot,R,z):
                                                   ctypes.c_int,
                                                   ndpointer(dtype=numpy.int32,flags=ndarrayFlags),
                                                   ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
+                                                  ctypes.c_void_p,
                                                   ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
                                                   ctypes.POINTER(ctypes.c_int)]
 
@@ -619,6 +626,7 @@ def eval_potential_c(pot,R,z):
                                        ctypes.c_int(npot),
                                        pot_type,
                                        pot_args,
+                                       pot_tfuncs,
                                        out,
                                        ctypes.byref(err))
 
@@ -645,11 +653,13 @@ def eval_force_c(pot,R,z,zforce=False):
        2013-01-29 - Written - Bovy (IAS)
     """
     from ..orbit.integrateFullOrbit import _parse_pot #here bc otherwise there is an infinite loop
+    from ..orbit.integratePlanarOrbit import _prep_tfuncs
     #Parse the potential
-    npot, pot_type, pot_args= _parse_pot(pot)
+    npot, pot_type, pot_args, pot_tfuncs= _parse_pot(pot)
+    pot_tfuncs= _prep_tfuncs(pot_tfuncs)
 
     #Set up result arrays
-    out= numpy.empty((len(R)))
+    out= numpy.empty(len(R))
     err= ctypes.c_int(0)
 
     #Set up the C code
@@ -664,6 +674,7 @@ def eval_force_c(pot,R,z,zforce=False):
                                                   ctypes.c_int,
                                                   ndpointer(dtype=numpy.int32,flags=ndarrayFlags),
                                                   ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
+                                                  ctypes.c_void_p,
                                                   ndpointer(dtype=numpy.float64,flags=ndarrayFlags),
                                                   ctypes.POINTER(ctypes.c_int)]
 
@@ -681,6 +692,7 @@ def eval_force_c(pot,R,z,zforce=False):
                                    ctypes.c_int(npot),
                                    pot_type,
                                    pot_args,
+                                   pot_tfuncs,
                                    out,
                                    ctypes.byref(err))
     
