@@ -1,24 +1,18 @@
-from __future__ import division, print_function
-
 import os
 import copy
 import pickle
-import numpy as nu
+import warnings
+import numpy
 from scipy import integrate
-import galpy.util.bovy_plot as plot
-from galpy.util import config
-from galpy.util.bovy_conversion import physical_conversion,\
-    potential_physical_input, freq_in_Gyr
+from ..util import plot, config, conversion
+from ..util.conversion import physical_conversion,\
+    potential_physical_input, physical_compatible
 from .Potential import Potential, PotentialError, lindbladR, flatten
+from .DissipativeForce import _isDissipative
 from .plotRotcurve import plotRotcurve
 from .plotEscapecurve import _INF, plotEscapecurve
-_APY_LOADED= True
-try:
-    from astropy import units
-except ImportError:
-    _APY_LOADED= False
-class planarPotential(object):
-    """Class representing 2D (R,\phi) potentials"""
+class planarPotential:
+    r"""Class representing 2D (R,\phi) potentials"""
     def __init__(self,amp=1.,ro=None,vo=None):
         self._amp= amp
         self.dim= 2
@@ -26,22 +20,19 @@ class planarPotential(object):
         self.isRZ= False
         self.hasC= False
         self.hasC_dxdv= False
+        self.hasC_dens= False
         # Parse ro and vo
         if ro is None:
             self._ro= config.__config__.getfloat('normalization','ro')
             self._roSet= False
         else:
-            if _APY_LOADED and isinstance(ro,units.Quantity):
-                ro= ro.to(units.kpc).value
-            self._ro= ro
+            self._ro= conversion.parse_length_kpc(ro)
             self._roSet= True
         if vo is None:
             self._vo= config.__config__.getfloat('normalization','vo')
             self._voSet= False
         else:
-            if _APY_LOADED and isinstance(vo,units.Quantity):
-                vo= vo.to(units.km/units.s).value
-            self._vo= vo
+            self._vo= conversion.parse_velocity_kms(vo)
             self._voSet= True
         return None
 
@@ -101,16 +92,29 @@ class planarPotential(object):
            2019-01-27 - Written - Bovy (UofT)
 
         """
+        from ..potential import flatten as flatten_pot
+        if not isinstance(flatten_pot([b])[0],(Potential,planarPotential)):
+            raise TypeError("""Can only combine galpy Potential"""
+                            """/planarPotential objects with """
+                            """other such objects or lists thereof""")
+        assert physical_compatible(self,b), \
+            """Physical unit conversion parameters (ro,vo) are not """\
+            """compatible between potentials to be combined"""
         if isinstance(b,list):
             return [self]+b
         else:
             return [self,b]
     # Define separately to keep order
     def __radd__(self,b):
-        if isinstance(b,list):
-            return b+[self]
-        else:
-            raise TypeError("Can only add a Force or Potential instance to another instance or to a list of such instances")
+        from ..potential import flatten as flatten_pot
+        if not isinstance(flatten_pot([b])[0],(Potential,planarPotential)):
+            raise TypeError("""Can only combine galpy Force objects with """
+                            """other Force objects or lists thereof""")
+        assert physical_compatible(self,b), \
+            """Physical unit conversion parameters (ro,vo) are not """\
+            """compatible between potentials to be combined"""
+        # If we get here, b has to be a list
+        return b+[self]
 
     def turn_physical_off(self):
         """
@@ -163,17 +167,15 @@ class planarPotential(object):
 
            2016-01-30 - Written - Bovy (UofT)
 
+           2020-04-22 - Don't turn on a parameter when it is False - Bovy (UofT)
+
         """
-        self._roSet= True
-        self._voSet= True
-        if not ro is None:
-            if _APY_LOADED and isinstance(ro,units.Quantity):
-                ro= ro.to(units.kpc).value
-            self._ro= ro
-        if not vo is None:
-            if _APY_LOADED and isinstance(vo,units.Quantity):
-                vo= vo.to(units.km/units.s).value
-            self._vo= vo
+        if not ro is False: self._roSet= True
+        if not vo is False: self._voSet= True
+        if not ro is None and ro:
+            self._ro= conversion.parse_length_kpc(ro)
+        if not vo is None and vo:
+            self._vo= conversion.parse_velocity_kms(vo)
         return None
 
     @potential_physical_input
@@ -217,7 +219,7 @@ class planarPotential(object):
         elif dR == 1 and dphi == 0:
             return -self.Rforce(R,phi=phi,t=t,use_physical=False)
         elif dR == 0 and dphi == 1:
-            return -self.phiforce(R,phi=phi,t=t,use_physical=False)
+            return -self.phitorque(R,phi=phi,t=t,use_physical=False)
         elif dR == 2 and dphi == 0:
             return self.R2deriv(R,phi=phi,t=t,use_physical=False)
         elif dR == 0 and dphi == 2:
@@ -230,7 +232,7 @@ class planarPotential(object):
     @potential_physical_input
     @physical_conversion('force',pop=True)
     def Rforce(self,R,phi=0.,t=0.):
-        """
+        r"""
         NAME:
 
            Rforce
@@ -265,17 +267,21 @@ class planarPotential(object):
         except AttributeError: #pragma: no cover
             raise PotentialError("'_Rforce' function not implemented for this potential")
 
-    @potential_physical_input
-    @physical_conversion('force',pop=True)
     def phiforce(self,R,phi=0.,t=0.):
+       warnings.warn('phiforce has been renamed phitorque, because it has always really been a torque (per unit mass); please switch to the new method name, because the old name will be removed in v1.9 and may be re-used for the actual phi force component',FutureWarning)
+       return self.phitorque(R,phi=phi,t=t)
+    
+    @potential_physical_input
+    @physical_conversion('energy',pop=True)
+    def phitorque(self,R,phi=0.,t=0.):
         """
         NAME:
 
-           phiforce
+           phitorque
 
         PURPOSE:
 
-           evaluate the phi force
+           evaluate the azimuthal torque = - d Phi / d phi
 
         INPUT:
 
@@ -287,21 +293,21 @@ class planarPotential(object):
 
         OUTPUT:
 
-           F_phi(R,(phi,t)))
+           tau_phi(R,(phi,t)))
 
         HISTORY:
 
            2010-07-13 - Written - Bovy (NYU)
 
         """
-        return self._phiforce_nodecorator(R,phi=phi,t=t)
+        return self._phitorque_nodecorator(R,phi=phi,t=t)
        
-    def _phiforce_nodecorator(self,R,phi=0.,t=0.):
+    def _phitorque_nodecorator(self,R,phi=0.,t=0.):
         # Separate, so it can be used during orbit integration
         try:
-            return self._amp*self._phiforce(R,phi=phi,t=t)
+            return self._amp*self._phitorque(R,phi=phi,t=t)
         except AttributeError: #pragma: no cover
-            raise PotentialError("'_phiforce' function not implemented for this potential")
+            raise PotentialError("'_phitorque' function not implemented for this potential")
 
     @potential_physical_input
     @physical_conversion('forcederivative',pop=True)
@@ -338,7 +344,7 @@ class planarPotential(object):
             raise PotentialError("'_R2deriv' function not implemented for this potential")      
 
     @potential_physical_input
-    @physical_conversion('forcederivative',pop=True)
+    @physical_conversion('energy',pop=True)
     def phi2deriv(self,R,phi=0.,t=0.):
         """
         NAME:
@@ -372,7 +378,7 @@ class planarPotential(object):
             raise PotentialError("'_phi2deriv' function not implemented for this potential")      
 
     @potential_physical_input
-    @physical_conversion('forcederivative',pop=True)
+    @physical_conversion('force',pop=True)
     def Rphideriv(self,R,phi=0.,t=0.):
         """
         NAME:
@@ -415,7 +421,7 @@ class planarPotential(object):
            Rrange - range (can be Quantity)
            grid - number of points to plot
            savefilename - save to or restore from this savefile (pickle)
-           +bovy_plot(*args,**kwargs)
+           +galpy.util.plot.plot(*args,**kwargs)
         OUTPUT:
            plot to output device
         HISTORY:
@@ -430,7 +436,7 @@ class planarAxiPotential(planarPotential):
         self.isNonAxi= False
         return None
     
-    def _phiforce(self,R,phi=0.,t=0.):
+    def _phitorque(self,R,phi=0.,t=0.):
         return 0.
 
     def _phi2deriv(self,R,phi=0.,t=0.): #pragma: no cover
@@ -471,7 +477,7 @@ class planarAxiPotential(planarPotential):
 
     @potential_physical_input
     @physical_conversion('velocity',pop=True)
-    def vcirc(self,R,phi=None):
+    def vcirc(self,R,phi=None,t=0.):
         """
         
         NAME:
@@ -490,6 +496,8 @@ class planarAxiPotential(planarPotential):
         
             phi= (None) azimuth to use for non-axisymmetric potentials
 
+            t - time (optional; can be Quantity)
+
         OUTPUT:
         
             circular rotation velocity
@@ -501,11 +509,11 @@ class planarAxiPotential(planarPotential):
             2016-06-15 - Added phi= keyword for non-axisymmetric potential - Bovy (UofT)
 
         """
-        return nu.sqrt(R*-self.Rforce(R,phi=phi,use_physical=False))
+        return numpy.sqrt(R*-self.Rforce(R,phi=phi,t=t,use_physical=False))
 
     @potential_physical_input
     @physical_conversion('frequency',pop=True)
-    def omegac(self,R):
+    def omegac(self,R,t=0.):
         """
         
         NAME:
@@ -521,6 +529,8 @@ class planarAxiPotential(planarPotential):
             Pot - Potential instance or list of such instances
         
             R - Galactocentric radius (can be Quantity)
+
+            t - time (optional; can be Quantity)
         
         OUTPUT:
         
@@ -531,11 +541,11 @@ class planarAxiPotential(planarPotential):
             2011-10-09 - Written - Bovy (IAS)
         
         """
-        return nu.sqrt(-self.Rforce(R,use_physical=False)/R)       
+        return numpy.sqrt(-self.Rforce(R,t=t,use_physical=False)/R)       
 
     @potential_physical_input
     @physical_conversion('frequency',pop=True)
-    def epifreq(self,R):
+    def epifreq(self,R,t=0.):
         """
         
         NAME:
@@ -549,6 +559,8 @@ class planarAxiPotential(planarPotential):
         INPUT:
         
            R - Galactocentric radius (can be Quantity)
+
+           t - time (optional; can be Quantity)
         
         OUTPUT:
         
@@ -559,11 +571,11 @@ class planarAxiPotential(planarPotential):
            2011-10-09 - Written - Bovy (IAS)
         
         """
-        return nu.sqrt(self.R2deriv(R,use_physical=False)
-                       -3./R*self.Rforce(R,use_physical=False))
+        return numpy.sqrt(self.R2deriv(R,t=t,use_physical=False)
+                       -3./R*self.Rforce(R,t=t,use_physical=False))
 
     @physical_conversion('position',pop=True)
-    def lindbladR(self,OmegaP,m=2,**kwargs):
+    def lindbladR(self,OmegaP,m=2,t=0.,**kwargs):
         """
         
         NAME:
@@ -581,6 +593,8 @@ class planarAxiPotential(planarPotential):
            m= order of the resonance (as in m(O-Op)=kappa (negative m for outer)
               use m='corotation' for corotation
               +scipy.optimize.brentq xtol,rtol,maxiter kwargs
+
+           t - time (optional; can be Quantity)
         
         OUTPUT:
         
@@ -591,13 +605,12 @@ class planarAxiPotential(planarPotential):
            2011-10-09 - Written - Bovy (IAS)
         
         """
-        if _APY_LOADED and isinstance(OmegaP,units.Quantity):
-            OmegaP= OmegaP.to(1/units.Gyr).value/freq_in_Gyr(self._vo,self._ro)
-        return lindbladR(self,OmegaP,m=m,use_physical=False,**kwargs)
+        OmegaP= conversion.parse_frequency(OmegaP,ro=self._ro,vo=self._vo)
+        return lindbladR(self,OmegaP,m=m,t=t,use_physical=False,**kwargs)
 
     @potential_physical_input
     @physical_conversion('velocity',pop=True)
-    def vesc(self,R):
+    def vesc(self,R,t=0.):
         """
 
         NAME:
@@ -614,6 +627,8 @@ class planarAxiPotential(planarPotential):
 
             R - Galactocentric radius (can be Quantity)
 
+            t - time (optional; can be Quantity)
+
         OUTPUT:
 
             escape velocity
@@ -623,8 +638,8 @@ class planarAxiPotential(planarPotential):
             2011-10-09 - Written - Bovy (IAS)
 
         """
-        return nu.sqrt(2.*(self(_INF,use_physical=False)
-                           -self(R,use_physical=False)))
+        return numpy.sqrt(2.*(self(_INF,t=t,use_physical=False)
+                           -self(R,t=t,use_physical=False)))
         
     def plotRotcurve(self,*args,**kwargs):
         """
@@ -644,7 +659,7 @@ class planarAxiPotential(planarPotential):
 
            savefilename - save to or restore from this savefile (pickle)
 
-           +bovy_plot(*args,**kwargs)
+           +galpy.util.plot.plot(*args,**kwargs)
 
         OUTPUT:
 
@@ -675,7 +690,7 @@ class planarAxiPotential(planarPotential):
 
            savefilename - save to or restore from this savefile (pickle)
 
-           +bovy_plot(*args,**kwargs)
+           +galpy.util.plot.plot(*args,**kwargs)
 
         OUTPUT:
 
@@ -711,10 +726,11 @@ class planarPotentialFromRZPotential(planarAxiPotential):
         self._Pot= RZPot
         self.hasC= RZPot.hasC
         self.hasC_dxdv= RZPot.hasC_dxdv
+        self.hasC_dens= RZPot.hasC_dens
         return None
 
     def _evaluate(self,R,phi=0.,t=0.):
-        """
+        r"""
         NAME:
            _evaluate
         PURPOSE:
@@ -731,7 +747,7 @@ class planarPotentialFromRZPotential(planarAxiPotential):
         return self._Pot(R,0.,t=t,use_physical=False)
             
     def _Rforce(self,R,phi=0.,t=0.):
-        """
+        r"""
         NAME:
            _Rforce
         PURPOSE:
@@ -788,6 +804,8 @@ def RZToplanarPotential(RZPot):
 
     """
     RZPot= flatten(RZPot)
+    if _isDissipative(RZPot):
+        raise NotImplementedError("Converting dissipative forces to 2D potentials is currently not supported")
     if isinstance(RZPot,list):
         out= []
         for pot in RZPot:
@@ -828,10 +846,11 @@ class planarPotentialFromFullPotential(planarPotential):
         self._Pot= Pot
         self.hasC= Pot.hasC
         self.hasC_dxdv= Pot.hasC_dxdv
+        self.hasC_dens= Pot.hasC_dens
         return None
 
     def _evaluate(self,R,phi=0.,t=0.):
-        """
+        r"""
         NAME:
            _evaluate
         PURPOSE:
@@ -848,7 +867,7 @@ class planarPotentialFromFullPotential(planarPotential):
         return self._Pot(R,0.,phi=phi,t=t,use_physical=False)
             
     def _Rforce(self,R,phi=0.,t=0.):
-        """
+        r"""
         NAME:
            _Rforce
         PURPOSE:
@@ -864,22 +883,22 @@ class planarPotentialFromFullPotential(planarPotential):
         """
         return self._Pot.Rforce(R,0.,phi=phi,t=t,use_physical=False)
 
-    def _phiforce(self,R,phi=0.,t=0.):
-        """
+    def _phitorque(self,R,phi=0.,t=0.):
+        r"""
         NAME:
-           _phiforce
+           _phitorque
         PURPOSE:
-           evaluate the azimuthal force
+           evaluate the azimuthal torque
         INPUT:
            R
            phi
            t
         OUTPUT:
-          F_phi(R(,\phi,t))
+          tau_phi(R(,\phi,t))
         HISTORY:
            2016-06-02 - Written - Bovy (UofT)
         """
-        return self._Pot.phiforce(R,0.,phi=phi,t=t,use_physical=False)
+        return self._Pot.phitorque(R,0.,phi=phi,t=t,use_physical=False)
 
     def _R2deriv(self,R,phi=0.,t=0.):
         """
@@ -971,7 +990,9 @@ def toPlanarPotential(Pot):
 
     """
     Pot= flatten(Pot)
-    if isinstance(Pot,list):
+    if _isDissipative(Pot):
+        raise NotImplementedError("Converting dissipative forces to 2D potentials is currently not supported")
+    elif isinstance(Pot,list):
         out= []
         for pot in Pot:
             if isinstance(pot,planarPotential):
@@ -1033,7 +1054,7 @@ def _evaluateplanarPotentials(Pot,R,phi=None,t=0.,dR=0,dphi=0):
     nonAxi= _isNonAxi(Pot)
     if nonAxi and phi is None:
         raise PotentialError("The (list of) planarPotential instances is non-axisymmetric, but you did not provide phi")
-    if isList and nu.all([isinstance(p,planarPotential) for p in Pot]):
+    if isList and numpy.all([isinstance(p,planarPotential) for p in Pot]):
         sum= 0.
         for pot in Pot:
             if nonAxi:
@@ -1090,7 +1111,7 @@ def _evaluateplanarRforces(Pot,R,phi=None,t=0.):
     if nonAxi and phi is None:
         raise PotentialError("The (list of) planarPotential instances is non-axisymmetric, but you did not provide phi")
     if isinstance(Pot,list) \
-            and nu.all([isinstance(p,planarPotential) for p in Pot]):
+            and numpy.all([isinstance(p,planarPotential) for p in Pot]):
         sum= 0.
         for pot in Pot:
             if nonAxi:
@@ -1106,17 +1127,21 @@ def _evaluateplanarRforces(Pot,R,phi=None,t=0.):
     else: #pragma: no cover 
         raise PotentialError("Input to 'evaluatePotentials' is neither a Potential-instance or a list of such instances")
 
-@potential_physical_input
-@physical_conversion('force',pop=True)
 def evaluateplanarphiforces(Pot,R,phi=None,t=0.):
+   warnings.warn('evaluateplanarphiforces has been renamed evaluateplanarphitorques, because it has always really been a torque (per unit mass); please switch to the new method name, because the old name will be removed in v1.9 and may be re-used for the actual phi force component',FutureWarning)
+   return evaluateplanarphitorques(Pot,R,phi=phi,t=t)
+
+@potential_physical_input
+@physical_conversion('energy',pop=True)
+def evaluateplanarphitorques(Pot,R,phi=None,t=0.):
     """
     NAME:
 
-       evaluateplanarphiforces
+       evaluateplanarphitorques
 
     PURPOSE:
 
-       evaluate the phiforce of a (list of) planarPotential instance(s)
+       evaluate the phitorque of a (list of) planarPotential instance(s)
 
     INPUT:
 
@@ -1130,35 +1155,35 @@ def evaluateplanarphiforces(Pot,R,phi=None,t=0.):
 
     OUTPUT:
 
-       F_phi(R(,phi,t))
+       tau_phi(R(,phi,t))
 
     HISTORY:
 
        2010-07-13 - Written - Bovy (NYU)
 
     """
-    return _evaluateplanarphiforces(Pot,R,phi=phi,t=t)
+    return _evaluateplanarphitorques(Pot,R,phi=phi,t=t)
 
-def _evaluateplanarphiforces(Pot,R,phi=None,t=0.):
+def _evaluateplanarphitorques(Pot,R,phi=None,t=0.):
     from .Potential import _isNonAxi
     isList= isinstance(Pot,list)
     nonAxi= _isNonAxi(Pot)
     if nonAxi and phi is None:
         raise PotentialError("The (list of) planarPotential instances is non-axisymmetric, but you did not provide phi")
     if isinstance(Pot,list) \
-            and nu.all([isinstance(p,planarPotential) for p in Pot]):
+            and numpy.all([isinstance(p,planarPotential) for p in Pot]):
         sum= 0.
         for pot in Pot:
             if nonAxi:
-                sum+= pot._phiforce_nodecorator(R,phi=phi,t=t)
+                sum+= pot._phitorque_nodecorator(R,phi=phi,t=t)
             else:
-                sum+= pot._phiforce_nodecorator(R,t=t)
+                sum+= pot._phitorque_nodecorator(R,t=t)
         return sum
     elif isinstance(Pot,planarPotential):
         if nonAxi:
-            return Pot._phiforce_nodecorator(R,phi=phi,t=t)
+            return Pot._phitorque_nodecorator(R,phi=phi,t=t)
         else:
-            return Pot._phiforce_nodecorator(R,t=t)
+            return Pot._phitorque_nodecorator(R,t=t)
     else: #pragma: no cover 
         raise PotentialError("Input to 'evaluatePotentials' is neither a Potential-instance or a list of such instances")
 
@@ -1199,7 +1224,7 @@ def evaluateplanarR2derivs(Pot,R,phi=None,t=0.):
     if nonAxi and phi is None:
         raise PotentialError("The (list of) planarPotential instances is non-axisymmetric, but you did not provide phi")
     if isinstance(Pot,list) \
-            and nu.all([isinstance(p,planarPotential) for p in Pot]):
+            and numpy.all([isinstance(p,planarPotential) for p in Pot]):
         sum= 0.
         for pot in Pot:
             if nonAxi:
@@ -1254,9 +1279,9 @@ def LinShuReductionFactor(axiPot,R,sigmar,nonaxiPot=None,
 
     """
     axiPot= flatten(axiPot)
-    from galpy.potential import omegac, epifreq
+    from ..potential import omegac, epifreq
     if nonaxiPot is None and (OmegaP is None or k is None or m is None):
-        raise IOError("Need to specify either nonaxiPot= or m=, k=, OmegaP= for LinShuReductionFactor")
+        raise OSError("Need to specify either nonaxiPot= or m=, k=, OmegaP= for LinShuReductionFactor")
     elif not nonaxiPot is None:
         OmegaP= nonaxiPot.OmegaP()
         k= nonaxiPot.wavenumber(R)
@@ -1264,10 +1289,10 @@ def LinShuReductionFactor(axiPot,R,sigmar,nonaxiPot=None,
     tepif= epifreq(axiPot,R)
     s= m*(OmegaP-omegac(axiPot,R))/tepif
     chi= sigmar**2.*k**2./tepif**2.
-    return (1.-s**2.)/nu.sin(nu.pi*s)\
-        *integrate.quad(lambda t: nu.exp(-chi*(1.+nu.cos(t)))\
-                            *nu.sin(s*t)*nu.sin(t),
-                        0.,nu.pi)[0]
+    return (1.-s**2.)/numpy.sin(numpy.pi*s)\
+        *integrate.quad(lambda t: numpy.exp(-chi*(1.+numpy.cos(t)))\
+                            *numpy.sin(s*t)*numpy.sin(t),
+                        0.,numpy.pi)[0]
 
 def plotplanarPotentials(Pot,*args,**kwargs):
     """
@@ -1291,7 +1316,7 @@ def plotplanarPotentials(Pot,*args,**kwargs):
 
        ncontours - number of contours to plot (if applicable)
 
-       +bovy_plot(*args,**kwargs) or bovy_dens2d(**kwargs)
+       +galpy.util.plot.plot(*args,**kwargs) or galpy.util.plot.dens2d(**kwargs)
 
     OUTPUT:
 
@@ -1306,23 +1331,16 @@ def plotplanarPotentials(Pot,*args,**kwargs):
     Rrange= kwargs.pop('Rrange',[0.01,5.])
     xrange= kwargs.pop('xrange',[-5.,5.])
     yrange= kwargs.pop('yrange',[-5.,5.])
-    if _APY_LOADED:
-        if hasattr(Pot,'_ro'):
-            tro= Pot._ro
-        else:
-            tro= Pot[0]._ro
-        if isinstance(Rrange[0],units.Quantity):
-            Rrange[0]= Rrange[0].to(units.kpc).value/tro
-        if isinstance(Rrange[1],units.Quantity):
-            Rrange[1]= Rrange[1].to(units.kpc).value/tro
-        if isinstance(xrange[0],units.Quantity):
-            xrange[0]= xrange[0].to(units.kpc).value/tro
-        if isinstance(xrange[1],units.Quantity):
-            xrange[1]= xrange[1].to(units.kpc).value/tro
-        if isinstance(yrange[0],units.Quantity):
-            yrange[0]= yrange[0].to(units.kpc).value/tro
-        if isinstance(yrange[1],units.Quantity):
-            yrange[1]= yrange[1].to(units.kpc).value/tro
+    if hasattr(Pot,'_ro'):
+        tro= Pot._ro
+    else:
+        tro= Pot[0]._ro
+    Rrange[0]= conversion.parse_length(Rrange[0],ro=tro)
+    Rrange[1]= conversion.parse_length(Rrange[1],ro=tro)
+    xrange[0]= conversion.parse_length(xrange[0],ro=tro)
+    xrange[1]= conversion.parse_length(xrange[1],ro=tro)
+    yrange[0]= conversion.parse_length(yrange[0],ro=tro)
+    yrange[1]= conversion.parse_length(yrange[1],ro=tro)
     grid= kwargs.pop('grid',100)
     gridx= kwargs.pop('gridx',100)
     gridy= kwargs.pop('gridy',gridx)
@@ -1341,22 +1359,22 @@ def plotplanarPotentials(Pot,*args,**kwargs):
         savefile.close()
     else:
         if nonAxi:
-            xs= nu.linspace(xrange[0],xrange[1],gridx)
-            ys= nu.linspace(yrange[0],yrange[1],gridy)
-            potR= nu.zeros((gridx,gridy))
+            xs= numpy.linspace(xrange[0],xrange[1],gridx)
+            ys= numpy.linspace(yrange[0],yrange[1],gridy)
+            potR= numpy.zeros((gridx,gridy))
             for ii in range(gridx):
                 for jj in range(gridy):
-                    thisR= nu.sqrt(xs[ii]**2.+ys[jj]**2.)
+                    thisR= numpy.sqrt(xs[ii]**2.+ys[jj]**2.)
                     if xs[ii] >= 0.:
-                        thisphi= nu.arcsin(ys[jj]/thisR)
+                        thisphi= numpy.arcsin(ys[jj]/thisR)
                     else:
-                        thisphi= -nu.arcsin(ys[jj]/thisR)+nu.pi
+                        thisphi= -numpy.arcsin(ys[jj]/thisR)+numpy.pi
                     potR[ii,jj]= evaluateplanarPotentials(Pot,thisR,
                                                           phi=thisphi,
                                                           use_physical=False)
         else:
-            Rs= nu.linspace(Rrange[0],Rrange[1],grid)
-            potR= nu.zeros(grid)
+            Rs= numpy.linspace(Rrange[0],Rrange[1],grid)
+            potR= numpy.zeros(grid)
             for ii in range(grid):
                 potR[ii]= evaluateplanarPotentials(Pot,Rs[ii],
                                                    use_physical=False)
@@ -1387,14 +1405,14 @@ def plotplanarPotentials(Pot,*args,**kwargs):
             kwargs['cntrls']= '-'
         ncontours= kwargs.pop('ncontours',10)
         if not 'levels' in kwargs:
-            kwargs['levels']= nu.linspace(nu.nanmin(potR),nu.nanmax(potR),ncontours)
-        return plot.bovy_dens2d(potR.T,
-                                xrange=xrange,
-                                yrange=yrange,**kwargs)
+            kwargs['levels']= numpy.linspace(numpy.nanmin(potR),numpy.nanmax(potR),ncontours)
+        return plot.dens2d(potR.T,
+                           xrange=xrange,
+                           yrange=yrange,**kwargs)
     else:
         kwargs['xlabel']=r"$R/R_0$"
         kwargs['ylabel']=r"$\Phi(R)$"
         kwargs['xrange']=Rrange
-        return plot.bovy_plot(Rs,potR,*args,**kwargs)
+        return plot.plot(Rs,potR,*args,**kwargs)
                               
     
